==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/docprops/lang/id.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'docprops', 'id', {
	bgColor: 'Warna Latar Belakang',
	bgFixed: 'Non-scrolling (Fixed) Background', // MISSING
	bgImage: 'Background Image URL', // MISSING
	charset: 'Character Set Encoding', // MISSING
	charsetASCII: 'ASCII', // MISSING
	charsetCE: 'Central European', // MISSING
	charsetCR: 'Cyrillic', // MISSING
	charsetCT: 'Chinese Traditional (Big5)', // MISSING
	charsetGR: 'Greek', // MISSING
	charsetJP: 'Japanese', // MISSING
	charsetKR: 'Korean', // MISSING
	charsetOther: 'Other Character Set Encoding', // MISSING
	charsetTR: 'Turkish', // MISSING
	charsetUN: 'Unicode (UTF-8)', // MISSING
	charsetWE: 'Western European', // MISSING
	chooseColor: 'Pilih',
	design: 'Design', // MISSING
	docTitle: 'Page Title', // MISSING
	docType: 'Document Type Heading', // MISSING
	docTypeOther: 'Other Document Type Heading', // MISSING
	label: 'Document Properties', // MISSING
	margin: 'Page Margins', // MISSING
	marginBottom: 'Bawah',
	marginLeft: 'Kiri',
	marginRight: 'Kanan',
	marginTop: 'Atas',
	meta: 'Meta Tags', // MISSING
	metaAuthor: 'Author', // MISSING
	metaCopyright: 'Copyright', // MISSING
	metaDescription: 'Document Description', // MISSING
	metaKeywords: 'Document Indexing Keywords (comma separated)', // MISSING
	other: 'Other...', // MISSING
	previewHtml: '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>', // MISSING
	title: 'Document Properties', // MISSING
	txtColor: 'Text Color', // MISSING
	xhtmlDec: 'Include XHTML Declarations' // MISSING
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/docprops/lang/id.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'docprops', 'id', {
	bgColor: 'Warna Latar Belakang',
	bgFixed: 'Non-scrolling (Fixed) Background', // MISSING
	bgImage: 'Background Image URL', // MISSING
	charset: 'Character Set Encoding', // MISSING
	charsetASCII: 'ASCII', // MISSING
	charsetCE: 'Eropa Tengah',
	charsetCR: 'Cyrillic', // MISSING
	charsetCT: 'Chinese Traditional (Big5)', // MISSING
	charsetGR: 'Bahasa Yunani',
	charsetJP: 'Bahasa Jepang',
	charsetKR: 'Bahasa Korea',
	charsetOther: 'Other Character Set Encoding', // MISSING
	charsetTR: 'Bahasa Turki',
	charsetUN: 'Unicode (UTF-8)', // MISSING
	charsetWE: 'Eropa Barat',
	chooseColor: 'Pilih',
	design: 'Tampilan',
	docTitle: 'Page Title', // MISSING
	docType: 'Document Type Heading', // MISSING
	docTypeOther: 'Other Document Type Heading', // MISSING
	label: 'Document Properties', // MISSING
	margin: 'Page Margins', // MISSING
	marginBottom: 'Bawah',
	marginLeft: 'Kiri',
	marginRight: 'Kanan',
	marginTop: 'Atas',
	meta: 'Meta Tags', // MISSING
	metaAuthor: 'Penulis',
	metaCopyright: 'Hak Cipta',
	metaDescription: 'Document Description', // MISSING
	metaKeywords: 'Document Indexing Keywords (comma separated)', // MISSING
	other: 'Other...', // MISSING
	previewHtml: '<p>This is some <strong>sample text</strong>. You are using <a href="javascript:void(0)">CKEditor</a>.</p>', // MISSING
	title: 'Document Properties', // MISSING
	txtColor: 'Warna Teks',
	xhtmlDec: 'Include XHTML Declarations' // MISSING
} );
